@@ -168,7 +168,7 @@ function  [ retval, sinterfaces, loaded_jars ]  = chk_spreadsheet_support (path_
     endif
     return
   elseif (dbug > 0)
-    printf ('\n');
+    printf ("\n");
   endif
 
   interfaces = {"COM", "POI", "POI+OOXML", "JXL", "OXS", "OTK", "JOD", "UNO", "OCT"}; 
@@ -247,7 +247,7 @@ function  [ retval, sinterfaces, loaded_jars ]  = chk_spreadsheet_support (path_
         printf ("  Maximum JVM memory: %5d MiB; ", jmem);
         if (jmem < 400)
           printf ("should better be at least 400 MB!\n");
-          printf ('    Hint: adapt setting -Xmx in file "java.opts" (supposed to be here:)\n');
+          printf ("    Hint: adapt setting -Xmx in file 'java.opts' (supposed to be here:)\n");
           printf ("    %s\n", [matlabroot filesep "share" filesep "octave" filesep "packages" filesep "java-<version>" filesep "java.opts\n"]);
         else
           printf ("sufficient.\n");
@@ -635,27 +635,27 @@ function [ retval ] = add_jars_to_jcp (path_to_jars, jarname, dbug)
   if (isempty (file))
     ## Still not found...
     if (dbug > 2)
-      printf ('  ? %s<...>.jar ?\n', jarname);
+      printf ("  ? %s<...>.jar ?\n", jarname);
     endif
   elseif (stat ([path_to_jars filesep file]).size < 1024)
     ## Probably too small for a jar => apparently a symlink
     if (dbug > 2)
-      printf ('  File %s is probably a symlink ... \n', file);
+      printf ("  File %s is probably a symlink ... \n", file);
     endif
   else
     ## FIXME: cache subdir in file name to speed up search
     if (dbug > 2)
-      printf ('  Found %s, adding it to javaclasspath ... ', file);
+      printf ("  Found %s, adding it to javaclasspath ... ", file);
     endif
     try
       javaaddpath ([path_to_jars filesep file]);
       if (dbug > 2)
-        printf ('OK\n');
+        printf ("OK\n");
       endif
       retval = [path_to_jars filesep file];
     catch
       if (dbug > 2)
-        printf ('FAILED\n');
+        printf ("FAILED\n");
       endif
     end_try_catch
   endif
