@@ -195,12 +195,20 @@ function [ ods ] = odsopen (filename, rw=0, reqinterface=[])
   ftype = 0;
   [~, ~, ext] = fileparts (filename);
   switch ext
+    case {"xls", ".xls"}
+      ## Because LibreOffice/OpenOffice.org accept Excel as well
+      ftype = 1;
+    case {"xlsx", "xlsm", ".xlsb", ".xlsx", ".xlsm", ".xlsb"}
+      ## Because LibreOffice/OpenOffice.org accept Excel as well
+      ftype = 2;
     case ".ods"               ## ODS 1.2
       ftype = 3;
     case ".sxc"               ## jOpenDocument (JOD) can read from .sxc files,
       ftype = 4;               ## but only if odfvsn = 2
     case ".gnumeric"          ## Zipped XML / gnumeric
       ftype = 5;
+    case ".csv"               ## ODS 1.2
+      ftype = 6;
     otherwise
   endswitch
 
@@ -227,17 +235,12 @@ function [ ods ] = odsopen (filename, rw=0, reqinterface=[])
               __JOD_spsh_open__ (ods, rw, filename, odssupport);
   endif
 
-  if (odsinterfaces.UNO && ! odssupport && ftype < 5)
-    ## Warn for LO / OOo stubbornness
-    if (ftype == 0 || ftype == 5 || ftype == 6)
-      warning ("UNO interface will write ODS format for unsupported file extensions\n")
-    endif
+  if (odsinterfaces.UNO && ! odssupport && ismember (ftype, [1:4, 6]))
     [ ods, odssupport, lastintf ] = ...
               __UNO_spsh_open__ (ods, rw, filename, odssupport);
   endif
 
-  if (odsinterfaces.OCT && ! odssupport && ...
-      (ftype == 2 || ftype == 3 || ftype == 5))
+  if (odsinterfaces.OCT && ! odssupport && ismember (ftype, [2, 3, 5]))
     [ ods, odssupport, lastintf ] = ...
               __OCT_spsh_open__ (ods, rw, filename, odssupport, ftype);
   endif
