@@ -18,19 +18,6 @@
 
 ## Author: Philip Nienhuis <prnienhuis@users.sf.net>
 ## Created: 2012-10-07
-## Updates (possibly from xlsopen):
-## 2011-05-18 Experimental UNO support added, incl. creating new spreadsheets
-## 2012-09-02 (in UNO section) web adresses need only two consecutive slashes
-## 2012-09-03 (in UNO section) replace canonicalize_file_name on non-Windows to
-##            make_absolute_filename (see bug #36677)
-## 2012-10-24 Style fixes
-## 2013-01-20 Adapted to ML-compatible Java calls
-## 2013-12-06 Updated copyright strings
-## 2014-01-01 First throw at input/output type filters
-## 2014-12-07 Add messages about 64-b Octave vs. 32-b LO / OOo
-##     ''     Style fixes
-## 2015-03-07 Replace deprecated strmatch
-##     ''     Extend arch match check
 
 function [ xls, xlssupport, lastintf ] = __UNO_spsh_open__ (xls, xwrite, filename, xlssupport)
 
