@@ -77,6 +77,8 @@ function [xlsinterfaces] = getxlsinterfaces (xlsinterfaces)
       endif
     endif
   endif
+  ## deflt signals that some default interface has been selected. Just used
+  ## for cosmetic purposes
   deflt = 0;
 
   ## Check if MS-Excel COM ActiveX server runs (only on Windows!)
@@ -243,8 +245,9 @@ function [xlsinterfaces] = getxlsinterfaces (xlsinterfaces)
   ##      Java interfaces should be in the has-java if-block
 
   if (deflt)
-    printf ("(* = default interface)\n"); 
+    printf ("(* = default interface)");
   endif
+  printf ("\n");
 
   ## FIXME the below stanza should be dropped once UNO is stable.
   # Echo a suitable warning about experimental status:
